@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Data::Delete;
-$Data::Delete::VERSION = '0.05';
+$Data::Delete::VERSION = '0.06';
 use Moo;
 use MooX::Types::MooseLike::Base qw/HashRef Bool/;
 
@@ -136,7 +136,7 @@ sub _delete_hash {
             }
 
             # Optionally delete an empty string value
-            elsif ( not $value and length($value) == 0 ) {
+            elsif ( length($value) == 0 ) {
                 delete $hashref->{$key} if $self->will_delete_empty_string;
             }
 
